@@ -2,6 +2,7 @@ from typing import Any, Dict, Optional
 
 import pytorch_lightning as pl
 from pytorch_lightning import Callback
+from pytorch_lightning.utilities.exceptions import MisconfigurationException
 
 
 class BaseCallback(Callback):
@@ -22,18 +23,28 @@ class BaseCallback(Callback):
         stop_after_epoch = stop_after_epoch or -1
 
         if apply_on_epoch < 0:
-            raise ValueError("`apply_on_epoch` is less than 0")
+            raise MisconfigurationException("`apply_on_epoch` is less than 0")
         if stop_after_epoch < -1:
-            raise ValueError("`stop_after_epoch` is less than -1")
+            raise MisconfigurationException("`stop_after_epoch` is less than -1")
         if apply_on_epoch > stop_after_epoch > -1:
-            raise ValueError("`apply_on_epoch` is greater to `stop_after_epoch`")
-        self.apply_on_epoch = apply_on_epoch
-        self.stop_after_epoch = stop_after_epoch
+            raise MisconfigurationException("`apply_on_epoch` is greater to `stop_after_epoch`")
+        self._apply_on_epoch = apply_on_epoch
+        self._stop_after_epoch = stop_after_epoch
         self._disable = False
 
     def __repr__(self) -> str:
         return "; ".join([f"{key}: {value}" for key, value in self._state.items()])
 
+    @property
+    def apply_on_epoch(self) -> int:
+        """Get an epoch after which the callback will work."""
+        return self._apply_on_epoch
+
+    @property
+    def stop_after_epoch(self) -> int:
+        """Get an epoch after which the callback will stop."""
+        return self._stop_after_epoch
+
     @property
     def disable(self) -> bool:
         """Show that a callback is disabled or not."""
@@ -45,18 +56,17 @@ class BaseCallback(Callback):
         return {"disable": self._disable}
 
     def on_before_accelerator_backend_setup(self, trainer: pl.Trainer, pl_module: pl.LightningModule) -> None:
-        """Disable any transforms for training data."""
+        """Disable a callback before starting."""
         self._disable = False
+        self._stop_after_epoch = trainer.max_epochs - 1 if self._stop_after_epoch == -1 else self._stop_after_epoch
 
     def on_train_epoch_start(self, trainer: pl.Trainer, pl_module: pl.LightningModule) -> None:
-        """Enable any transforms for training data."""
+        """Enable a callback."""
         if trainer.current_epoch == self.apply_on_epoch:
             self._disable = False
 
-    def on_train_epoch_end(
-        self, trainer: pl.Trainer, pl_module: pl.LightningModule, unused: Optional[int] = None
-    ) -> None:
-        """Disable any transforms training data."""
+    def on_train_epoch_end(self, trainer: pl.Trainer, pl_module: pl.LightningModule) -> None:
+        """Disable a callback."""
         if trainer.current_epoch == self.stop_after_epoch:
             self._disable = True
 
