@@ -4,6 +4,7 @@ import numpy as np
 
 from ..utils.type_hints import IntegerScalar, NPType
 from .base import IReader
+from .functional import get_one_hot
 
 
 class ScalarReader(IReader):
@@ -52,34 +53,4 @@ class ScalarReader(IReader):
         return output
 
 
-def get_one_hot(label: int, num_classes: int, smoothing: Optional[float] = None) -> IntegerScalar:
-    """Apply OneHot vectorization to a giving scalar, optional with label smoothing.
-
-    Args:
-        label: scalar value to be vectorized
-        num_classes: total number of classes
-        smoothing: if specified applies label smoothing
-
-    Returns:
-        a one-hot vector with shape (num_classes,)
-    """
-    assert num_classes > 0, f"Expect num_classes to be > 0, got {num_classes}"
-
-    assert 0 <= label < num_classes, f"Expect label to be in [0; {num_classes}), got {label}"
-
-    if smoothing is not None:
-        assert 0.0 < smoothing < 1.0, f"If smoothing is specified it must be in (0; 1), got {smoothing}"
-
-        smoothed = smoothing / float(num_classes - 1)
-        result = np.full((num_classes,), smoothed, dtype=np.float32)
-        result[label] = 1.0 - smoothing
-
-        return result
-
-    result = np.zeros(num_classes, dtype=np.float32)
-    result[label] = 1.0
-
-    return result
-
-
 __all__ = ["ScalarReader"]
